kdiagram.plot.taylor\_diagram.plot\_taylor\_diagram\_in
=======================================================

.. currentmodule:: kdiagram.plot.taylor_diagram

.. autofunction:: plot_taylor_diagram_in